@@ -293,8 +293,7 @@ public class UriBuilderImpl extends UriBuilder implements Cloneable {
         }
     }
     //CHECKSTYLE:OFF
-    @SuppressWarnings("PMD.ExcessiveParameterList")
-    private String substituteVarargs(URITemplate templ,
+    private String substituteVarargs(URITemplate templ, //NOPMD
                                      Map<String, Object> alreadyResolvedTs,
                                      Map<String, Object> alreadyResolvedTsPathEnc,
                                      Map<String, Object> alreadyResolvedTsEnc,
@@ -614,7 +613,7 @@ public class UriBuilderImpl extends UriBuilder implements Cloneable {
 
     @Override
     public UriBuilder scheme(String s) throws IllegalArgumentException {
-        scheme = s;
+        scheme = (s != null) ? s.toLowerCase() : s;
         return this;
     }
 
