@@ -22,15 +22,15 @@ package org.apache.cxf.jaxws.support;
 import java.lang.reflect.Method;
 import java.util.Iterator;
 
-import javax.jws.WebMethod;
-import javax.jws.WebService;
-import javax.jws.soap.SOAPBinding;
 import javax.wsdl.Definition;
 import javax.wsdl.Service;
 import javax.wsdl.factory.WSDLFactory;
 import javax.wsdl.xml.WSDLReader;
 import javax.xml.namespace.QName;
 
+import jakarta.jws.WebMethod;
+import jakarta.jws.WebService;
+import jakarta.jws.soap.SOAPBinding;
 import org.apache.cxf.Bus;
 import org.apache.cxf.binding.BindingFactoryManager;
 import org.apache.cxf.service.model.MessageInfo;
@@ -177,8 +177,8 @@ public class JaxWsServiceConfigurationTest {
     }
 
     @WebService(name = "Hello", targetNamespace = "http://cxf.com/")
-    @SOAPBinding(parameterStyle = javax.jws.soap.SOAPBinding.ParameterStyle.BARE,
-                 style = javax.jws.soap.SOAPBinding.Style.RPC, use = javax.jws.soap.SOAPBinding.Use.LITERAL)
+    @SOAPBinding(parameterStyle = jakarta.jws.soap.SOAPBinding.ParameterStyle.BARE,
+                 style = jakarta.jws.soap.SOAPBinding.Style.RPC, use = jakarta.jws.soap.SOAPBinding.Use.LITERAL)
     public interface Hello {
         @WebMethod(operationName = "sayHi", exclude = false)
         String sayHi();
@@ -196,18 +196,18 @@ public class JaxWsServiceConfigurationTest {
         String sayHello(String asdf1, String asdf2);
     }
 
-    @SOAPBinding(style = javax.jws.soap.SOAPBinding.Style.RPC)
+    @SOAPBinding(style = jakarta.jws.soap.SOAPBinding.Style.RPC)
     public interface HelloRPC {
         String sayHi();
     }
 
-    @SOAPBinding(style = javax.jws.soap.SOAPBinding.Style.DOCUMENT)
+    @SOAPBinding(style = jakarta.jws.soap.SOAPBinding.Style.DOCUMENT)
     public interface HelloWrapped {
         String sayHi();
     }
 
-    @SOAPBinding(parameterStyle = javax.jws.soap.SOAPBinding.ParameterStyle.BARE,
-                 style = javax.jws.soap.SOAPBinding.Style.DOCUMENT)
+    @SOAPBinding(parameterStyle = jakarta.jws.soap.SOAPBinding.ParameterStyle.BARE,
+                 style = jakarta.jws.soap.SOAPBinding.Style.DOCUMENT)
     public interface HelloBare {
         String sayHi();
     }
