@@ -18,9 +18,9 @@
  */
 package org.apache.cxf.systest.ws.rm.policy;
 
-import javax.jws.WebMethod;
-import javax.jws.WebParam;
-import javax.jws.WebService;
+import jakarta.jws.WebMethod;
+import jakarta.jws.WebParam;
+import jakarta.jws.WebService;
 
 @WebService(targetNamespace = "http://ws.samples.apache.org/",
             serviceName = "GreetingService", portName = "GreetingServicePort",
